@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003-2004 Rein Couperus <pa0r@amsat.org>
+ * Copyright (C) 2001-2002-2003-2004-2005 Rein Couperus <pa0r@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -578,6 +578,7 @@ int testaudio() {
 
 float testvalue;
 char key = '\0';
+int runnit = 1;
 
 clear();
 
@@ -586,8 +587,6 @@ scanmenu();
 /* ------------initialize sound card --------*/
 init_audio();
 
-int runnit = 1;
-
 while (runnit == 1) {
 
 	testvalue = get_audio_sample();
@@ -671,7 +670,8 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
-				strcat(commands, ph_message[0]);
+ 				strcat(commands, " ");			// (W9WI)
+ 				strcat(commands, ph_message[0]);
 				system (commands);
 				runnit = 0;
 				break;
@@ -682,6 +682,7 @@ struct dirent *soundfilename;
 
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+				strcat(commands, " ");			// (W9WI)
 				strcat(commands, ph_message[1]);
 				system (commands);
 				runnit = 0;
@@ -692,6 +693,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");			// (W9WI)
 				strcat(commands, ph_message[2]);
 				system (commands);
 				runnit = 0;
@@ -702,6 +704,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+				strcat(commands, " ");			// (W9WI)
 				strcat(commands, ph_message[3]);
 				system (commands);
 				runnit = 0;
@@ -712,6 +715,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[4]);
 				system (commands);
 				runnit = 0;
@@ -722,6 +726,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[5]);
 				system (commands);
 				runnit = 0;
@@ -732,6 +737,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[6]);
 				system (commands);
 				runnit = 0;
@@ -742,6 +748,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[7]);
 				system (commands);
 				runnit = 0;
@@ -752,6 +759,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[8]);
 				system (commands);
 				runnit = 0;
@@ -762,6 +770,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[9]);
 				system (commands);
 				runnit = 0;
@@ -772,6 +781,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[10]);
 				system (commands);
 				runnit = 0;
@@ -782,6 +792,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[11]);
 				system (commands);
 				runnit = 0;
@@ -793,6 +804,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[12]);
 				system (commands);
 				runnit = 0;
@@ -804,6 +816,7 @@ struct dirent *soundfilename;
 				refresh();
 				strcpy(commands,"rec -w -r 8000 -d ");
 				strcat(commands, sc_device);
+ 				strcat(commands, " ");				// (W9WI)
 				strcat(commands, ph_message[13]);
 				system (commands);
 				runnit = 0;
@@ -827,7 +840,7 @@ struct dirent *soundfilename;
 				runnit = 0;
 				break;
 			case '3' :
-				sounddir = opendir("/home/rein/tlf/soundlogs/");
+ 				sounddir = opendir("$HOME/tlf/soundlogs/");		// (W9WI)
 
 				if (sounddir == NULL) break;
 
