@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003-2004 Rein Couperus <pa0r@eudxf.org>
+ * Copyright (C) 2001-2002-2003-2004-2005 Rein Couperus <pa0r@eudxf.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,10 @@ extern int no_arrows;
 extern int isdupe;			// LZ3NY auto-b4 patch
 extern int contest;
 extern int dxped;
+extern int cwstart;
+extern int sending_call;
 extern char hiscall[];
+extern char hiscall_sent[];
 extern char comment[];
 extern char call[];
 extern int cqmode;
@@ -57,7 +60,7 @@ extern int cluster;
 extern int announcefilter;
 extern char buffer[];
 extern char message[15][80];
-extern char ph_message[14][40];
+extern char ph_message[14][80];
 extern int cury, curx;
 extern float freq;
 extern float mem;
@@ -86,6 +89,7 @@ extern int nroflines;
 extern int bandmap_pos;
 extern int allspots;
 extern int nob4;
+extern int change_rst;
 extern int weight;
 extern int k_tune;
 extern int tune_val;
@@ -222,6 +226,21 @@ printcall();
 				 	edit_last();
 					break;
 			}
+			case 153:										// start sending call if cw mode
+			case 32:
+			{
+				if (trxmode == CWMODE && contest == 1) {
+					strcpy (buffer, hiscall);
+					sending_call = 1;
+					sendbuf();
+					sending_call = 0;
+					strcpy (hiscall_sent, hiscall);
+					printcall();
+					x = 153;
+					break;
+				} else
+					break;
+			}
 			case 155:		/* left */
 		 	{
 
@@ -435,7 +454,7 @@ printcall();
 
 			case 156:                                               /* pgup */
 			{
-				  if (strlen(hiscall) != 0){
+				  if ((change_rst == 1)&&(strlen(hiscall) != 0)){	// change RST
 
 					if (his_rst[1] <= 56){
 
@@ -445,7 +464,7 @@ printcall();
 						mvprintw(12, 29, hiscall);
 					}
 
-				  } else {
+				  } else {											// change cw speed
  						keyspeed = speedup();
 						strncpy(speedbuf, speedstr +  (2  *  keyspeed), 2);
 						speedbuf[2] =  '\0';
@@ -478,7 +497,7 @@ printcall();
 
 			case 157:                                               /* pgdown */
 			{
-				  if (strlen(hiscall) != 0) {
+				  if ((change_rst == 1)&&(strlen(hiscall) != 0)) {
 
 					if (his_rst[1] >= 49){
 				 	 	his_rst[1]--;
@@ -506,7 +525,7 @@ printcall();
 			}
 			case 413 :	{			// ctrl-pgdown, cqdelay (not for TERM=linux)
 		 			
-					if (cqdelay >= 1){
+					if (cqdelay >= 4){
 				 		cqdelay--;
 				 		attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
 
@@ -1198,6 +1217,15 @@ printcall();
 						instring[1]='\0';
 						addch(x);
 						strcat(hiscall, instring);
+						if (cwstart != 0 && trxmode == CWMODE && contest == 1) {
+							if (strlen(hiscall) == cwstart) {
+								strcpy (buffer, hiscall);
+								sending_call = 1;
+								sendbuf();
+								sending_call = 0;
+								strcpy (hiscall_sent, hiscall);
+							}	
+						}
 					}
 
 					refresh();
