@@ -23,7 +23,7 @@
 #include "gettxinfo.h"
 #include "time_update.h"
 #ifdef HAVE_LIBHAMLIB
-#include "rig.h"
+#include <hamlib/rig.h>
 #endif
 
 int (change_freq)(void);
