@@ -1,3 +1,22 @@
+/*
+ * Tlf - contest logging program for amateur radio operators
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
 #include "getwwv.h"
 
 int getwwv(void) {
@@ -7,6 +26,7 @@ extern char lastwwv[];
 extern char backgrnd_str[];
 extern double r;
 extern int mycountrynr;
+extern int timeoffset;
 
 char printbuffer[81] = "";
 char *i;
@@ -19,24 +39,10 @@ double sfi, d;
 time_t now;
 struct tm *ptr1;
 
-FILE *fp;
 
-
-//	if (r == 0)
-//		return(1);                                  /* nothing to do */
-	
-	if  ( (fp = fopen("wwvfile","r"))  == NULL){							
-			mvprintw(24, 0, "Error opening WWV_file");
-			refresh();
-			sleep(2);
-	}else {						
-						
-	attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);						
+ 	attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
 	mvprintw(24,0,  backgrnd_str);
 
-	fgets (lastwwv, 75,  fp);
-	fclose(fp);					
-    }
 
 	if (strlen(lastwwv) >= 2){
 
@@ -78,7 +84,7 @@ FILE *fp;
 			
 			i = strstr(lastwwv, "act");
         	if (i != NULL)
-				strcat (printbuffer, "     active  ");
+				strcat (printbuffer, " act  ");
 		
 			i = strstr(lastwwv, "Au=au");		
 			if (i != NULL)
@@ -90,8 +96,11 @@ FILE *fp;
 	    	strncpy (timediffstr, datalines[mycountrynr] +  60, 6);  /* GMT difference */
  			timediffstr[6] = '\0';
  			d = atof(timediffstr);
- 			now = (time(0) + (-1 * d * 3600));
- 			ptr1 =  localtime (&now);
+
+//			d -= timeoffset;
+
+			now = (time(0) + ((timeoffset-d) * 3600));
+ 			ptr1 =  gmtime (&now);
  			strftime(timebuff, 80,  "%H:%M",  ptr1);
 	    	
 	    	
