@@ -109,6 +109,7 @@
   int sectn_mult=0;
   int dx_arrlsections = 0;
   int serial_section_mult = 0;
+  int serial_grid4_mult = 0;
   int qso_once = 0;
   int addcallarea_once = 0;
   int noleadingzeros;
@@ -151,6 +152,7 @@
   int contest = 0;		        /* 0 =  General,  1  = contest */
   int announcefilter  = FILTER_ANN;	/*  filter cluster  announcements */
   int showscore_flag = 0;		/* show  score window */
+  int change_rst = 0;
   char exchange[40];
   char sp_return[80] = " \n";
   char cq_return[80] = " \n";
@@ -166,6 +168,9 @@
   						" ?\n"," QRZ?\n"," PSE K\n","TEST % %\n","@ [\n","TU %\n","","","","","","","","","","",""};
   char ph_message[14][80] = {"","","","","","","","","","","",""}; 		// voice keyer file names
   char hiscall[20];
+  char hiscall_sent[20] = "";
+  int cwstart = 0;
+  int sending_call = 0;
   char lastcall[20];
   char lastcomment[40];
   char qsonrstr[5] =  "0001";
