@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ * Copyright (C) 2001-2002-2003-2004-2005 Rein Couperus <pa0r@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,64 +21,20 @@
  	*                       items
  	*--------------------------------------------------------------*/
 
-#include "makelogline.h"                                                      
+#include "globalvars.h"
+#include "makelogline.h"
 
 int makelogline(void)
 {
-extern char logline4[];
-extern char band[9][4];
-extern int bandinx;
-extern int trxmode;
-extern char qsonrstr[];
-extern char my_rst[];
-extern char his_rst[];
-extern char hiscall[];
-extern char lastcall[];
-extern char hiscall[];
-extern char comment[];
-extern char lastcomment[];
-extern int wpx;
-extern char pxstr[];
-extern int cqww;
-extern int pacc_pa_flg;
-extern int universal;
-extern int country_mult;
-extern int shownewmult;
-extern char mults[MAX_MULTS][12];
-extern int addcallarea;
-extern int arrldx_usa;
-extern int arrl_fd;
-extern int dxped;
-extern int contest;
-extern int addcty;
-extern int addzone;
-extern int wysiwyg_multi;
-extern int dx_arrlsections;
-extern char pointstring[];
-extern char datalines[MAX_DATALINES][81];
-extern struct tm *time_ptr;
-extern int one_point;
-extern int two_point;
-extern int three_point;
-extern int lan_active;
-extern int exchange_serial;
-extern char lastqsonr[];
-extern int arrlss;
-extern char ssexchange[];
-extern char section[];
-extern char zone_export[];
-extern char zone_fix[];
-extern int universal;
-extern int serial_section_mult;
-extern int sectn_mult;
-extern int countrynr;
-extern int w_cty;
-extern int ve_cty;
 
 
 static char time_buf[80];
 char fillspaces[50] = "                              ";
 int points=0;
+static int lastbandinx = 0;
+char grid[5] = "";
+int sr_nr = 0;
+int i;
 
 
 logline4[0] = '\0' ;
@@ -87,6 +43,13 @@ get_time();
 
 strftime(time_buf, 60, " %d-%b-%y %H:%M ",  time_ptr);
 
+if (wpx == 1) {  	// 10 minute timer
+	if (lastbandinx != bandinx) {
+		lastbandinx = bandinx;
+		minute_timer = 600;		// 10 minutes
+	}
+}
+
 strcat (logline4, band[bandinx]);
 
 if (trxmode == CWMODE)
@@ -105,8 +68,14 @@ if ((lan_active ==1) && (exchange_serial == 1)) {
 else
 	strcat (logline4, qsonrstr) ;
 
+if (lan_active == 1 && cqwwm2 == 1)
+{
+	logline4[27] = thisnode;		// set node ID...
+	logline4[28] = '\0';
+	strcat (logline4, " ");
+} else
+	strcat (logline4, "  ");
 
-strcat (logline4, "  ");
 strcat (logline4, hiscall);        		/*  29 */
 lastcall[0] = '\0';                     /* remember  for edit  */
 strcat(lastcall, hiscall);
@@ -136,8 +105,22 @@ if (arrlss == 1) {         // ----------------------------arrlss----------------
 
 } else if (serial_section_mult == 1) {          //-------------------------serial_section---------------
 
-	sprintf(logline4+54, "%4d %s", atoi(ssexchange), section);
+	sprintf(logline4+54, "%s", comment);
+
 	section[0]='\0';
+} else if (serial_grid4_mult == 1) {          //-------------------------serial_grid 4 characters---------------
+
+	sr_nr = atoi(comment);
+	for (i=0; i<11; i++) {
+		if (comment[i] > 64 && comment[i] < 91) {
+			break;	
+		}
+	}
+	strncpy(grid, comment+i, 6);
+	grid[6]='\0';
+		
+	sprintf(logline4+54, "%4.0d %s", sr_nr, grid);
+	section[4] = '\0';
 
 } else if (sectn_mult == 1) {          //-------------------------section only---------------
 
@@ -145,7 +128,7 @@ if (arrlss == 1) {         // ----------------------------arrlss----------------
 	section[0]='\0';
 
 
-} else if (cqww == 1) {          //-------------------------cqww----------------
+} else if ((cqww == 1) || (wazmult==1) || (itumult==1)) {          //-------------------------cqww----------------
 /*
 	if (strlen(zone_fix) > 1) {
 		strcat (logline4, zone_fix);
@@ -173,7 +156,7 @@ if ((add_pfx()  ==  0) && (wpx == 1)){                    /* wpx */
 } else strncat (logline4, fillspaces, 5);
 
 
-if (cqww == 1){                                    /* ------------cqww ---------------------*/
+if ((cqww == 1) || (wazmult==1) || (itumult==1)) {                                    /* ------------cqww ---------------------*/
      logline4[68]='\0';
 
      if (addcty != 0){
@@ -190,33 +173,33 @@ if (cqww == 1){                                    /* ------------cqww ---------
      		logline4[71] = '\0';
      	}
 
-	strcat (logline4, " ");
-	logline4[72]='\0';
+		strcat (logline4, " ");
+		logline4[72]='\0';
      	addcty = 0 ;
-     } else strcat (logline4, "    ");
+     } else {
+	 	strcat (logline4, "    ");
+	 }
 
      if (addzone != 0){
 /*
-	if (strlen(zone_fix) > 1) {
-		strncat (logline4, zone_fix, 2);
-	} else
-		strncat (logline4, zone_export, 2);
+		if (strlen(zone_fix) > 1) {
+			strncat (logline4, zone_fix, 2);
+		} else
+			strncat (logline4, zone_export, 2);
 */
-	if (strlen(comment) < 2){
-		strcat (logline4, "0");
-		strncat (logline4, comment, 1);
-	}else
-		strncat (logline4, comment, 2);
+		if (strlen(comment) < 2){
+			strcat (logline4, "0");
+			strncat (logline4, comment, 1);
+		}else
+			strncat (logline4, comment, 2);
 
-	strcat(logline4, "   ");
-     	addzone = 0;
+		strcat(logline4, "   ");
+  		addzone = 0;
     }else {
-     		strcat (logline4, "     ");
-
-	zone_fix[0]='\0';
-
-   }
-			//----------------------------------end cqww-----------------
+    	strcat (logline4, "     ");
+		zone_fix[0]='\0';
+   	}
+//----------------------------------end cqww-----------------
 
 } else if (arrldx_usa == 1){
       logline4[68]='\0';
@@ -241,7 +224,8 @@ if (cqww == 1){                                    /* ------------cqww ---------
 
  } else if ((dx_arrlsections == 1) && (countrynr != w_cty) && (countrynr != ve_cty)){
       logline4[68]='\0';
-      if (addcty != 0){
+
+	  if (addcty != 0){
      	strncat (logline4, datalines[addcty]+ 69, 3);
      	if (logline4[69] == ':'){
      		logline4[69] = '\0';
@@ -257,10 +241,14 @@ if (cqww == 1){                                    /* ------------cqww ---------
 
      	strcat (logline4, "     ");
 
-      } else
+      } else {
      		strncat  (logline4,  fillspaces, 9);
+	  }
+} else if ((wysiwyg_multi == 1)
+	|| (serial_section_mult == 1)
+	|| (sectn_mult == 1)
+	|| (serial_grid4_mult)){
 
-} else if ((wysiwyg_multi == 1) || (serial_section_mult == 1) || (sectn_mult == 1) ){
        logline4[68]='\0';
 
 	  if (shownewmult >= 0){
