@@ -112,7 +112,7 @@ int parse_logcfg(char *inputbuffer){
 
 	extern int use_rxvt;
 	extern char message[15][80];
-	extern char ph_message[14][40];
+	extern char ph_message[14][80];
 	extern char sp_return[];
 	extern char cq_return[];
 	extern char call[];
@@ -183,6 +183,7 @@ int parse_logcfg(char *inputbuffer){
 	extern int multlist;
 	extern int universal;
 	extern int serial_section_mult;
+	extern int serial_grid4_mult;
 	extern int sectn_mult;
 	extern int dx_arrlsections;
 	extern int pfxmult;
@@ -388,7 +389,7 @@ extern int nobandchange;
 		"CWBANDWIDTH=",
 		"LOWBAND_DOUBLE",		/* 145 */
 		"CLUSTER_LOG",
-		"",
+		"SERIAL+GRID4",
 		"",
 		""
 		
@@ -566,7 +567,7 @@ extern int nobandchange;
 				buff[0] = '\0';
 				strcat(buff, inputbuffer + 5);
 				if ((atoi(buff) > -1) && (atoi(buff) < 1001)){
-					strcpy(tonestr, buff);
+					strncpy(tonestr, buff,4);
 					tonestr[3] = '\0';
 				}
 				break;
@@ -967,6 +968,9 @@ extern int nobandchange;
 			case 103 ... 111: {	// get phone messages
 				strncpy (ph_message[ii-103], inputbuffer+5, 70);
 				ph_message[ii-103][strlen(ph_message[ii-103]) -1] = '\0';
+ 				mvprintw(15,5,"A: Phone message #%d is %s",ii-103,ph_message[ii-103]); // (W9WI)
+ 				refresh();
+ //				system ("sleep 2");
 				if (strlen(ph_message[ii-103]) > 0)
 					use_vk = 1;
 				break;
@@ -974,6 +978,9 @@ extern int nobandchange;
 			case 112 ... 116: {	// get phone messages
 				strncpy (ph_message[ii-103], inputbuffer+6, 39);
 				ph_message[ii-103][strlen(ph_message[ii-103]) -1] = '\0';
+ 				mvprintw(15,5,"B: Phone message #%d is %s",ii-103,ph_message[ii-103]);  // (W9WI)
+ 				refresh();
+ //				system ("sleep 2");
 				if (strlen(ph_message[ii-103]) > 0)
 					use_vk = 1;
 				break;
@@ -988,8 +995,13 @@ extern int nobandchange;
 			}
 			case 119: {	// CQ Delay (sec)
 				char buff[4];
-				if (strlen(inputbuffer)>=9) cqdelay = atoi(strncpy(buff,inputbuffer+8,3));
-                if ((cqdelay<3)||(cqdelay>=120)) cqdelay=8;
+				if (strlen(inputbuffer)>=9) {
+					strncpy(buff,inputbuffer+8,3);
+					cqdelay = atoi(buff);
+				}
+                if ((cqdelay<8)||(cqdelay>=120)) 
+                	cqdelay=20;
+                	
 				break;
 			}
  			case 120: {	// wpx style prefixes mult
@@ -1160,6 +1172,10 @@ extern int nobandchange;
 					clusterlog = 1;
 					break;
 			}
+			case 147 : {
+					serial_grid4_mult = 1;
+					break;
+			}
 
 		}
 
