@@ -35,10 +35,11 @@
 		extern int dataindex[MAX_DBLINES];
 		extern char datalines[MAX_DATALINES][81];
 
-    	char buf[81] = "";
+//    	char buf[81] = "";	### bug fix
+	    	char buf[181] = "";
 		char buffer[80];
 		char ctydb_location[80];
-    	int  n = 0, i = 0, j  = 0, k = 0, o = 0, m = 0;
+	    	int  n = 0, i = 0, j  = 0, k = 0, o = 0, m = 0;
 		static int nrofpfx=0;
 		char * cqloc;
 		char * ituloc;
@@ -75,7 +76,8 @@
 
     while ( !feof(fp_db))
     {
-     	fgets (buf,  180,  fp_db);
+//     	fgets (buf,  180,  fp_db);		### bug fix
+     	fgets (buf,  sizeof(buf),  fp_db);
 
 		if (buf[0] == '\n') continue;
 
