@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ * Copyright (C) 2001-2002-2003-2004-2005 Rein Couperus <pa0r@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,8 @@ extern char lastqsonr[];
 extern int noleadingzeros;
 extern int arrlss;
 extern int keyerport;
+extern char hiscall_sent[];
+extern int sending_call;
 
 static char comstr[80] = "";
 static char comstr2[2];
@@ -59,6 +61,7 @@ static char rst_out[4] = "";
 
 size_t loc;
 int i, nr;
+
 	
   comstr[0]='\0';
   comstr2[0] = '\0';
@@ -67,7 +70,7 @@ int i, nr;
 
   if (arrlss == 1) shortqsonr = 0;
 
-  if ((trxmode == CWMODE) && (keyerport != NO_KEYER)){
+  if ((trxmode == CWMODE || trxmode == DIGIMODE) && (keyerport != NO_KEYER)){
 
 	loc = strcspn(buffer,  "%");                      /* mycall */
 	
@@ -87,9 +90,14 @@ int i, nr;
 	
 	while ((strlen(buffer) -  loc)  > 1){
 	
-        if (loc != 0)
-			strncat (comstr, buffer, loc );	 	
-	 		strcat (comstr,  hiscall);
+        if (loc != 0) strncat (comstr, buffer, loc );
+        	if (strlen(hiscall_sent) == 0) { 	
+	 			strcat (comstr,  hiscall);
+	 		} else {
+	 			strcat (comstr, hiscall + strlen(hiscall_sent));
+	 			hiscall_sent[0] = '\0';
+//	 			sending_call = 0;
+	 		}
 	 		strcat (comstr, buffer  + loc + 1);
 	 		strcpy (buffer,  comstr);
 	 		strcpy  (comstr,  "");
@@ -136,7 +144,7 @@ int i, nr;
 	
 	while ((strlen(buffer) - loc) >  1){
 	
-        		if (loc != 0)
+        	if (loc != 0)
 			strncat (comstr, buffer, loc);
 
 		if (noleadingzeros == 1) {
@@ -157,29 +165,41 @@ int i, nr;
 
 		strcpy (buffer,  comstr);
 
-			if ((lan_active ==1) && (exchange_serial == 1)){
-				strncpy(lastqsonr, qsonrstr, 5);
- 				send_lan_message(INCQSONUM, qsonrstr) ;
-			}
+
+		if ((lan_active ==1) && (exchange_serial == 1)){
+			strncpy(lastqsonr, qsonrstr, 5);
+ 			send_lan_message(INCQSONUM, qsonrstr) ;
+		}
 
 
 		strcpy (comstr, "");
 
 	 	loc = strcspn(buffer,  "#");
 	}
-		
-		if ((strlen(buffer) + strlen(termbuf)) < 80 ) {
-			if (simulator == 0) strcat(termbuf, buffer);
-	 	}
-		attron(COLOR_PAIR(7) | A_STANDOUT);
 
-		if (simulator == 0) strncat(printlinebuffer, termbuf, strlen(termbuf) - 1 );
+	if ((strlen(buffer) + strlen(termbuf)) < 80 ) {
+		if (simulator == 0) strcat(termbuf, buffer);
+//		if (sending_call == 1) {
+//			strcat (termbuf, " ");
+//			sending_call = 0;
+//		}
+	}
 
+	attron(COLOR_PAIR(7) | A_STANDOUT);
+
+
+		if (simulator == 0) 
+			strncat(printlinebuffer, termbuf, strlen(termbuf) - 1 );
+		else
+			strncat(printlinebuffer, termbuf, strlen(termbuf) );
+	
+	
+	
 	if (searchflg  == 0 && simulator == 0)
 		strncat (printlinebuffer, backgrnd_str, 80 - strlen(printlinebuffer));
 	else
 		strncat (printlinebuffer, backgrnd_str, 40 - strlen(printlinebuffer));
-	
+
 
 	if ((simulator_mode == 0)){
 		mvprintw(5, 0,  printlinebuffer);
@@ -191,21 +211,48 @@ int i, nr;
 				attron(COLOR_PAIR(COLOR_WHITE));
 				mvaddstr(cury,curx,"");
 				 refresh();
-				
+
+				 if (trxmode == DIGIMODE) {
+
+					if (data_ready != 1) {
+						if (keyerport == MFJ1278_KEYER){
+						int i=0;
+							for (i = 0; i < strlen(buffer); i++)
+								if (buffer[i] == '\n') buffer[i] = 13;
+							for (i = 0; i < strlen(buffer); i++)
+								if (buffer[i] == 123) buffer[i] = 20;
+							for (i = 0; i < strlen(buffer); i++)
+								if (buffer[i] == 125) buffer[i] = 18;
+						}
+						strcat(wkeyerbuffer, buffer);
+						buffer[0] = '\0';
+						data_ready = 1;
+					}else
+						buffer[0] = '\0';
+				}
+
+
+
 				if (trxmode == CWMODE) {
 
 					if (data_ready != 1) {
+						if (keyerport == MFJ1278_KEYER){
+						int i=0;
+							for (i = 0; i < strlen(buffer); i++)
+								if (buffer[i] == '\n') buffer[i] = 13;
+						}
 						strcat(wkeyerbuffer, buffer);
 						if (keyerport == NET_KEYER){
 		 					netkeyer(K_MESSAGE, wkeyerbuffer);
 							wkeyerbuffer[0]='\0';
 							data_ready = 0;
-						}
-//						data_ready = 1;
+						} else
+							data_ready = 1;
+
 					}else
 						buffer[0] = '\0';
 				}
-				
+
 				getyx(stdscr, cury,  curx);
 				attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT );
 				mvaddstr(0,0,"   ");
@@ -213,7 +260,7 @@ int i, nr;
 				mvaddstr(cury,curx,"");
 				
     		if (simulator == 0){
-				displayit();
+					if (sending_call == 0) displayit();
     				refresh();
 		  }
 
