@@ -30,7 +30,7 @@ extern int trx_control;
 //extern RIG *my_rig;
 extern freq_t outfreq;
 #else
-extern int my_rig;
+//extern int my_rig;
 extern int outfreq;
 #endif
 
@@ -390,7 +390,8 @@ const char eom[2] = {'\015' , '\0'};
 
 	if(native_rig_fd > 0) {
 
-			i = read (native_rig_fd, inputline, RIG_BUFFERSIZE-1);
+//			i = read (native_rig_fd, inputline, RIG_BUFFERSIZE-1);	### bug fix
+			i = read (native_rig_fd, inputline, sizeof(inputline));
 
 			if (strncmp(inputline, "Z!",2) != 0) {
 				rignumber = 2000;				// ORION
@@ -522,7 +523,11 @@ return(0);
 int  native_rig_reset_rit(int rignumber){
 
 extern int native_rig_fd;
+#ifdef HAVE_LIBHAMLIB                    //code for Hamlib interface
+extern freq_t outfreq;
+#else
 extern int outfreq;
+#endif
 
 char line[20] = "*RMR0";
 const char eom[2] = {'\015' , '\0'};		// ORION
@@ -545,7 +550,8 @@ extern int native_rig_fd;
 
 char buffer[10];
 
-sprintf(buffer, "%s%d%c%", "*CS", speed, '\015');
+//sprintf(buffer, "%s%d%c%", "*CS", speed, '\015');	### bug fix
+sprintf(buffer, "%s%d%c", "*CS", speed, '\015');
 
 	if (native_rig_fd > 0)
 		write (native_rig_fd, buffer, strlen(buffer));
