@@ -36,12 +36,14 @@
 	extern double range;
 	extern int timeoffset;
 	extern int timecorr;
+ 	extern char itustr[];
+	extern int countrynr;
+	extern int mycountrynr;
  	
  	char bufstr[81];
- 	char pxstr[6];
+ 	char pxstr[16];
  	char countrystr[26];
  	char zonestr[3];
- 	char itustr[3];
  	char contstr[3]  = "";
  	char timediffstr[7];
  	char timebuff[80];
@@ -82,7 +84,8 @@
  	 	strncpy (zonestr, cqzone, 2);
  	 	zonestr[2] = '\0';
  	}
- 	if (strlen(ituzone) < 2){
+
+  if (strlen(ituzone) < 2){
  		strncpy (itustr, datalines[x] +  31, 2);  /* itu zone */
  		itustr[2] = '\0';
 	}
@@ -105,7 +108,8 @@
 	C_DEST_Lat[6] = '\0';
 	C_DEST_Long[7] = '\0';
 
-	qrb();
+	if (countrynr != 0 && countrynr != mycountrynr)
+		qrb();
 	
  	strncpy (contstr, datalines[x] +  36, 2);  /* continent */
  	contstr[2] = '\0';
@@ -114,17 +118,23 @@
  	attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
  	if (x == 1)
  		mvprintw(24, 0,  "                                                                                        ");
- 	else{
+ 	else
+	{
  		mvprintw(24,0, " %s  %s             ",  pxstr, countrystr);
- 		if (x > 0) {
- 			
+
+		if (x > 0)
+		{
  			mvprintw(24,26,  " %s %s                                           ", contstr, zonestr );
 
- 			mvprintw(24,26,  " %s %s   %.0f km/%.0f deg ", contstr, zonestr,  range, bearing);
- 		}	
+ 			if (x != 0 && x != mycountrynr)
+				mvprintw(24,26,  " %s %s   %.0f km/%.0f deg ", contstr, zonestr,  range, bearing);
+			else
+				mvprintw(24,26,  " %s %s                            ", contstr, zonestr);
+
+ 		}
  		else
- 			mvprintw(24,26,  " %s %s  ", contstr, zonestr);
-		
+ 			mvprintw(24,26,  " %s %s                        ", contstr, zonestr);
+
  		mvprintw(24, 66, "DX time: %s", timebuff);
  	}
 		if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD );
